==> xwxapt-3.1.tar.bz2: xwxapt-3.1/src/interface.h <==
/*
 *  This program is free software; you can redistribute it and/or
 *  modify it under the terms of the GNU General Public License as
 *  published by the Free Software Foundation; either version 3 of
 *  the License, or (at your option) any later version.
 *
 *  This program is distributed in the hope that it will be useful,
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *  GNU General Public License for more details:
 *
 *  http://www.gnu.org/copyleft/gpl.txt
 */

#ifndef INTERFACE_H
#define INTERFACE_H		1

#include "common.h"

/* Gtk Builder object ids */
#define ERROR_DIALOG_IDS \
"error_dialog", \
"error_ok_button", \
"error_quit_button", \
NULL

#define POPUP_MENU_IDS \
"popup_menu", \
"operation_timer", \
"start_stop_timer", \
"cancel_timer", \
"select_satellite", \
"select_satellite_menu", \
"meteor", \
"decode_from_dsp", \
"record_to_file", \
"decode_from_file", \
"stop", \
"quit", \
NULL

#define MAIN_WINDOW_IDS \
"main_window", \
"image_scrolledwindow", \
"viewport", \
"apt_image", \
"receive_togglebutton", \
"normalize_togglebutton", \
"colorize_togglebutton", \
"invert_togglebutton", \
"sat_label", \
"text_scrolledwindow", \
"textview", \
"demod_drawingarea", \
"level_setup_togglebutton", \
"signal_lev", \
"err_label", \
"status_frame", \
"sync_ind", \
"sync_lev", \
"gain_label", \
"gain_hscale", \
"gain_adj", \
"auto_checkbutton", \
"offset_label", \
"offset_checkbutton", \
"dagc_checkbutton", \
"tuner_label", \
"bw_entry", \
"freq_entry", \
"dft_drawingarea", \
"subcarrier_radiobutton", \
"carrier_radiobutton", \
NULL

#define FILECHOOSER_IDS \
"filechooser", \
NULL

#define QUIT_DIALOG_IDS \
"quit_dialog", \
"quit_cancel_button", \
NULL

#define START_STOP_IDS \
"startstop_timer", \
"startstop_time_cancel", \
"startstop_time_ok", \
NULL

#define TIMER_DIALOG_IDS \
"timer_dialog", \
"timer_okbutton", \
"timer_adj", \
"spinbutton", \
NULL

#endif

==> xwxapt-3.4.2.tar.bz2: xwxapt-3.4.2/src/interface.h <==
/*
 *  This program is free software; you can redistribute it and/or
 *  modify it under the terms of the GNU General Public License as
 *  published by the Free Software Foundation; either version 3 of
 *  the License, or (at your option) any later version.
 *
 *  This program is distributed in the hope that it will be useful,
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *  GNU General Public License for more details:
 *
 *  http://www.gnu.org/copyleft/gpl.txt
 */

#ifndef INTERFACE_H
#define INTERFACE_H		1

#include "common.h"

/* Gtk Builder object ids */
#define ERROR_DIALOG_IDS \
"error_dialog", \
"error_ok_button", \
"error_quit_button", \
NULL

#define POPUP_MENU_IDS \
"popup_menu", \
"operation_timer", \
"start_stop_timer", \
"cancel_timer", \
"select_satellite", \
"select_satellite_menu", \
"meteor", \
"decode_from_dsp", \
"record_to_file", \
"decode_from_file", \
"stop", \
"quit", \
NULL

#define MAIN_WINDOW_IDS \
"main_window", \
"image_scrolledwindow", \
"viewport", \
"apt_image", \
"receive_togglebutton", \
"normalize_togglebutton", \
"colorize_togglebutton", \
"invert_togglebutton", \
"sat_label", \
"text_scrolledwindow", \
"textview", \
"demod_drawingarea", \
"level_setup_togglebutton", \
"signal_lev", \
"err_label", \
"status_frame", \
"sync_ind", \
"sync_lev", \
"gain_label", \
"gain_hscale", \
"gain_adj", \
"auto_checkbutton", \
"offset_label", \
"offset_checkbutton", \
"dagc_checkbutton", \
"tuner_label", \
"bw_entry", \
"freq_entry", \
"ifft_drawingarea", \
"subcarrier_radiobutton", \
"carrier_radiobutton", \
NULL

#define FILECHOOSER_IDS \
"filechooser", \
NULL

#define QUIT_DIALOG_IDS \
"quit_dialog", \
"quit_cancel_button", \
NULL

#define START_STOP_IDS \
"startstop_timer", \
"startstop_time_cancel", \
"startstop_time_ok", \
NULL

#define TIMER_DIALOG_IDS \
"timer_dialog", \
"timer_okbutton", \
"timer_adj", \
"spinbutton", \
NULL

#endif
